pub struct NormalizationContract {
pub schema_version: String,
pub field_rules: Vec<FieldRule>,
}Expand description
The canonical normalization contract.
Encapsulates all rules needed to transform a raw conformance event into its normalized form suitable for comparison.
Fields
schema_version: StringSchema version this contract was defined against.
field_rules: Vec<FieldRule>Field-level rules (by key name).
Implementations
Sourceimpl NormalizationContract
impl NormalizationContract
Sourcepub fn normalize(&self, value: &mut Value, ctx: &NormalizationContext)
pub fn normalize(&self, value: &mut Value, ctx: &NormalizationContext)
Normalize a conformance event in-place.
Applies all rules from this contract: key-based field replacement, path canonicalization, ANSI stripping, UUID/run-ID/port rewriting.
Sourcepub fn normalize_and_canonicalize(
&self,
value: Value,
ctx: &NormalizationContext,
) -> Value
pub fn normalize_and_canonicalize( &self, value: Value, ctx: &NormalizationContext, ) -> Value
Normalize and canonicalize (sort keys) for stable comparison.