pub struct NavigateTreeResult {
pub editor_text: Option<String>,
pub cancelled: bool,
pub aborted: bool,
pub summary_entry: Option<SessionEntry>,
}Expand description
Outcome of AgentSession::navigate_tree.
Fields
editor_text: Option<String>User-message text to place in the editor when navigating to a user message.
cancelled: boolTrue when an extension cancelled the navigation.
aborted: boolTrue when the summarization step was aborted by cancellation.
summary_entry: Option<SessionEntry>Created branch-summary entry, when a summary was produced.