parse_source

Function parse_source 

pub fn parse_source(source: &str) -> ParsedSource
TypeScript parseSource: delegate to the shared resolver parser so install paths and identities match PackagePathResolver exactly.

This is a free function (not an associated function on PackageManager) so callers do not have to fix the Runner type parameter.