pub fn write_debug_dump(input: &DebugDumpInput<'_>) -> Result<PathBuf>Expand description
Render and atomically write a dump to the host debug log path.
Returns the path written.
Errors
Propagates write_debug_dump_atomically failures.
pub fn write_debug_dump(input: &DebugDumpInput<'_>) -> Result<PathBuf>Render and atomically write a dump to the host debug log path.
Returns the path written.
Propagates write_debug_dump_atomically failures.