pub enum SettingsManagerError {
ProjectNotTrusted,
InvalidSetting {
setting: &'static str,
value: String,
},
}Expand description
Errors thrown synchronously by SettingsManager methods.
Variants
ProjectNotTrusted
Project write attempted while the project is not trusted.
InvalidSetting
Invalid value passed to, or stored in, a numeric setting.