pub struct EventDispatcher { /* private fields */ }Expand description
Dispatches events to extension handlers.
Implementations
Sourceimpl EventDispatcher
impl EventDispatcher
pub fn new<R>(runtime: R) -> Selfwhere
R: Into<ExtensionRuntimeHandle>,
Sourcepub async fn dispatch_with_context<R: DeserializeOwned>(
&self,
event: ExtensionEvent,
ctx_payload: Value,
timeout_ms: u64,
) -> Result<Option<R>>
pub async fn dispatch_with_context<R: DeserializeOwned>( &self, event: ExtensionEvent, ctx_payload: Value, timeout_ms: u64, ) -> Result<Option<R>>
Dispatch an event with an explicit context payload and timeout.
Sourcepub async fn dispatch<R: DeserializeOwned>(
&self,
event: ExtensionEvent,
) -> Result<Option<R>>
pub async fn dispatch<R: DeserializeOwned>( &self, event: ExtensionEvent, ) -> Result<Option<R>>
Dispatch an event with an empty context payload and default timeout.