pub enum PreflightVerdict {
Pass,
Warn,
Fail,
}Expand description
Overall verdict from preflight analysis.
Variants
Pass
Extension is expected to work without issues.
Warn
Extension may work but some features could be degraded.
Fail
Extension is likely to fail at load or runtime.