pub fn classify_extension_path(
extension_id: &str,
path: &Path,
policy: &ExtensionPolicy,
) -> InstallTimeRiskReportExpand description
Run both the preflight analyzer and security scanner on extension files at a given path and produce a composite install-time risk report.