pub struct SecurityScanner;Expand description
Scans extension source for security-sensitive patterns and produces a deterministic risk classification report.
Implementations
Sourceimpl SecurityScanner
impl SecurityScanner
Sourcepub fn scan_source(extension_id: &str, source: &str) -> SecurityScanReport
pub fn scan_source(extension_id: &str, source: &str) -> SecurityScanReport
Scan raw source text and produce a security scan report.