Extension tools integration.
This module provides adapters that allow JavaScript extension-registered tools to be used as
normal Rust Tool implementations inside the agent tool registry.
Structs
- Extension
Tool Wrapper - Wraps a JS extension-registered tool so it can be used as a Rust
Tool. - Wasm
Extension Tool Wrapper
Functions
- collect_
extension_ tool_ wrappers - Collect all registered extension tools and wrap them as Rust
Tools.