pub struct IncidentBundleFilter {
pub start_ms: Option<i64>,
pub end_ms: Option<i64>,
pub extension_id: Option<String>,
pub alert_categories: Option<Vec<SecurityAlertCategory>>,
pub min_severity: Option<SecurityAlertSeverity>,
}Expand description
Filter criteria for scoping an incident evidence bundle.
Fields
start_ms: Option<i64>If set, only include entries with ts_ms >= start_ms.
end_ms: Option<i64>If set, only include entries with ts_ms <= end_ms.
extension_id: Option<String>If set, only include entries matching this extension id.
alert_categories: Option<Vec<SecurityAlertCategory>>If set, only include alerts of these categories.
min_severity: Option<SecurityAlertSeverity>If set, only include alerts at or above this severity.