pub struct RuntimeRiskBaselineModel {
pub schema: String,
pub extension_id: String,
pub generated_at_ms: i64,
pub source_data_hash: String,
pub source_entry_count: usize,
pub capability_profiles: Vec<BaselineCapabilityProfile>,
pub transition_matrix: BaselineMarkovTransitionMatrix,
pub anomaly_threshold_mads: f64,
pub transition_divergence_threshold: f64,
}Expand description
Complete baseline model for an extension, built from approved traces.
Fields
schema: StringSchema version.
extension_id: StringExtension ID this baseline covers.
generated_at_ms: i64Timestamp when baseline was generated (ms since epoch).
source_data_hash: StringSource data hash from the ledger used to build this baseline.
source_entry_count: usizeNumber of ledger entries used to build the baseline.
capability_profiles: Vec<BaselineCapabilityProfile>Per-capability robust statistics.
transition_matrix: BaselineMarkovTransitionMatrixMarkov transition matrix over risk states.
anomaly_threshold_mads: f64MAD deviation threshold for flagging anomalies (default: 3.0).
transition_divergence_threshold: f64KL divergence threshold for transition anomalies (default: 0.5).