apply_proposal

Function apply_proposal 

pub fn apply_proposal(
    proposal: &PatchProposal,
    mode: RepairMode,
    extension_root: Option<&Path>,
) -> Result<ApplicationResult, Vec<ProposalValidationError>>
Apply a validated proposal (dry-run: only validates and reports).

In the current implementation, actual file modifications are deferred to the module loader. This function validates and produces an audit record of what would be applied.