pub struct ChecksumEntry {
pub relative_path: String,
pub checksum: ArtifactChecksum,
pub size_bytes: u64,
}Expand description
A single artifact entry in a golden checksum manifest.
Fields
relative_path: StringRelative path of the artifact within the extension root.
checksum: ArtifactChecksumSHA-256 checksum.
size_bytes: u64Byte size of the artifact.