PiJsTickStats

Struct PiJsTickStats 

pub struct PiJsTickStats {
Show 14 fields pub ran_macrotask: bool, pub microtask_drains: usize, pub jobs_drained: usize, pub pending_hostcalls: usize, pub hostcalls_total: u64, pub hostcalls_timed_out: u64, pub memory_used_bytes: u64, pub peak_memory_used_bytes: u64, pub repairs_total: u64, pub module_cache_hits: u64, pub module_cache_misses: u64, pub module_cache_invalidations: u64, pub module_cache_entries: u64, pub module_disk_cache_hits: u64,
}
Statistics from a tick execution.

Fields

ran_macrotask: bool

Whether a macrotask was executed.

microtask_drains: usize

Number of microtask drain iterations.

jobs_drained: usize

Number of pending QuickJS jobs drained.

pending_hostcalls: usize

Number of pending hostcalls (in-flight Promises).

hostcalls_total: u64

Total hostcalls issued by this runtime.

hostcalls_timed_out: u64

Total hostcalls timed out by this runtime.

memory_used_bytes: u64

Last observed QuickJS memory_used_size in bytes.

peak_memory_used_bytes: u64

Peak observed QuickJS memory_used_size in bytes.

repairs_total: u64

Number of auto-repair events recorded since the runtime was created.

module_cache_hits: u64

Number of module cache hits accumulated by this runtime.

module_cache_misses: u64

Number of module cache misses accumulated by this runtime.

module_cache_invalidations: u64

Number of module cache invalidations accumulated by this runtime.

module_cache_entries: u64

Number of module entries currently retained in the cache.

module_disk_cache_hits: u64

Number of disk cache hits (transpiled source loaded from persistent storage).