pub struct RepairRule {
pub id: &'static str,
pub version: &'static str,
pub pattern: RepairPattern,
pub description: &'static str,
}Expand description
A static repair rule with deterministic ordering and versioning.
Fields
id: &'static strUnique identifier for the rule (e.g. "dist_to_src_v1").
version: &'static strSemantic version of this rule’s logic.
pattern: RepairPatternWhich RepairPattern this rule implements.
description: &'static strHuman-readable description of what the rule does.
Implementations
Sourceimpl RepairRule
impl RepairRule
Sourcepub const fn risk(&self) -> RepairRisk
pub const fn risk(&self) -> RepairRisk
Risk tier inherited from the pattern.
Sourcepub const fn is_allowed_by(&self, mode: RepairMode) -> bool
pub const fn is_allowed_by(&self, mode: RepairMode) -> bool
Whether this rule can fire under the given mode.