pub enum ContentionSignature {
InsufficientSamples,
ReadDominant,
MixedContention,
WriterStarvationRisk,
WriteDominant,
}Expand description
Deterministic contention signature computed from a fixed observation window.
Variants
InsufficientSamples
Window does not include enough operations for a stable decision.
ReadDominant
Read-dominant contention with healthy writer behavior.
MixedContention
Mixed read/write contention without starvation indicators.
WriterStarvationRisk
Writer wait/timeout profile indicates starvation risk.
WriteDominant
Write-dominant contention (or low reader pressure).