pub struct SessionIndex { /* private fields */ }Implementations
Sourceimpl SessionIndex
impl SessionIndex
pub fn new() -> Self
pub fn for_sessions_root(root: &Path) -> Self
pub fn index_session(&self, session: &Session) -> Result<()>
Sourcepub fn index_session_snapshot(
&self,
path: &Path,
header: &SessionHeader,
message_count: u64,
name: Option<String>,
) -> Result<()>
pub fn index_session_snapshot( &self, path: &Path, header: &SessionHeader, message_count: u64, name: Option<String>, ) -> Result<()>
Update index metadata for an already-persisted session snapshot.
This avoids requiring a full Session clone when callers already have
header + aggregate entry stats.
pub fn list_sessions(&self, cwd: Option<&str>) -> Result<Vec<SessionMeta>>
pub fn delete_session_path(&self, path: &Path) -> Result<()>
pub fn reindex_all(&self) -> Result<()>
Sourcepub fn should_reindex(&self, max_age: Duration) -> bool
pub fn should_reindex(&self, max_age: Duration) -> bool
Check whether the on-disk index is stale enough to reindex.
Sourcepub fn reindex_if_stale(&self, max_age: Duration) -> Result<bool>
pub fn reindex_if_stale(&self, max_age: Duration) -> Result<bool>
Reindex the session database if the index is stale.