Module session_picker

Module session_picker 

Session picker TUI for selecting from available sessions.

Provides an interactive list for choosing which session to resume.

Structs

SessionPicker
The session picker TUI model.

Functions

format_time
Format a timestamp for display.
list_sessions_for_cwd
List sessions for the current working directory using the session index.
list_sessions_for_project
pick_session
Run the session picker and return the selected session.
truncate_session_id
Truncate a session id by character count for display.