pub async fn refresh_cache_if_stale(client: &Client) -> VersionCheckResultExpand description
Refresh the cached latest-release version when the cache is missing, stale, or malformed. Returns the resulting status after the refresh attempt.
pub async fn refresh_cache_if_stale(client: &Client) -> VersionCheckResultRefresh the cached latest-release version when the cache is missing, stale, or malformed. Returns the resulting status after the refresh attempt.