pub fn parse_package_command(args: &[String]) -> Option<PackageCommandOptions>Expand description
Parse pi <subcommand> [rest…].
Returns None when the first token is not a recognized package subcommand.
Otherwise returns the fully resolved options including conflict checks.
Mirrors parsePackageCommand in package-manager-cli.ts:189-387.