pub struct PiJsTickStats {Show 14 fields
pub ran_macrotask: bool,
pub microtask_drains: usize,
pub jobs_drained: usize,
pub pending_hostcalls: usize,
pub hostcalls_total: u64,
pub hostcalls_timed_out: u64,
pub memory_used_bytes: u64,
pub peak_memory_used_bytes: u64,
pub repairs_total: u64,
pub module_cache_hits: u64,
pub module_cache_misses: u64,
pub module_cache_invalidations: u64,
pub module_cache_entries: u64,
pub module_disk_cache_hits: u64,
}Expand description
Statistics from a tick execution.
Fields
ran_macrotask: boolWhether a macrotask was executed.
microtask_drains: usizeNumber of microtask drain iterations.
jobs_drained: usizeNumber of pending QuickJS jobs drained.
pending_hostcalls: usizeNumber of pending hostcalls (in-flight Promises).
hostcalls_total: u64Total hostcalls issued by this runtime.
hostcalls_timed_out: u64Total hostcalls timed out by this runtime.
memory_used_bytes: u64Last observed QuickJS memory_used_size in bytes.
peak_memory_used_bytes: u64Peak observed QuickJS memory_used_size in bytes.
repairs_total: u64Number of auto-repair events recorded since the runtime was created.
module_cache_hits: u64Number of module cache hits accumulated by this runtime.
module_cache_misses: u64Number of module cache misses accumulated by this runtime.
module_cache_invalidations: u64Number of module cache invalidations accumulated by this runtime.
module_cache_entries: u64Number of module entries currently retained in the cache.
module_disk_cache_hits: u64Number of disk cache hits (transpiled source loaded from persistent storage).