pub fn check_cached() -> VersionCheckResultExpand description
Check the latest version from cache or return None if cache is stale/missing.
The actual HTTP check is performed separately (by the caller spawning a background task with the HTTP client).